@@ -64,7 +64,7 @@ sub _prepare {
 	my $on_header = $$opt{on_header};
 	my $on_body   = $$opt{on_body};
 
-	$easy->setopt(CURLOPT_WRITEHEADER, \ my $headers);
+	$easy->setopt(CURLOPT_WRITEHEADER, \ my $_headers);
 
 	my $body = "";
 	$easy->setopt(CURLOPT_FILE, \$body) unless $on_body;
@@ -82,6 +82,8 @@ sub _prepare {
 
 	$easy->setopt(CURLOPT_FORBID_REUSE, $$opt{persistent} ? 0 : 1) if exists $$opt{persistent};
 
+	my ($is_success, $headers, $redirects);
+
 	my $max_size = $$opt{max_size};
 	my $aborted_by_max_size = 0;
 
@@ -93,7 +95,7 @@ sub _prepare {
 			my $size = length $data;
 			$body_size += $size;
 			if ($on_header) {
-				my ($is_success, $headers, $redirects) = _headers($easy, $url, $headers);
+				($is_success, $headers, $redirects) = _headers($easy, $url, $_headers);
 				my $r = $on_header->($is_success, $headers, $redirects);
 				$on_header = undef;
 				$r or return 0;
@@ -117,8 +119,8 @@ sub _prepare {
 	my $finish = sub {
 		my ($easy, $result) = @_;
 
-		if ($headers) {
-			my ($is_success, $headers, $redirects) = _headers($easy, $url, $headers);
+		if ($_headers) {
+			($is_success, $headers, $redirects) = _headers($easy, $url, $_headers) unless $headers;
 			if ($result == CURLE_WRITE_ERROR and $aborted_by_max_size) {
 				$is_success = 0;
 				$$headers{"Status"} = 599;
